@@ -1,7 +1,10 @@
+import warnings
+
 from lesscode.utils.EsUtil import es_condition_by_terms, es_condition_by_wildcard
 
 
 def format_param_tag(bool_should_more_list, especial_tag_list):
+    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
     bool_should_list = []
     if especial_tag_list is not None:
         for tag in especial_tag_list:
@@ -37,7 +40,8 @@ def format_param_tag(bool_should_more_list, especial_tag_list):
                 es_condition_by_terms(bool_should_list, "tags.market_tag.status", ["新三板挂牌"])
             if tag in ["已上市", "排队上市", "已退市"]:
                 es_condition_by_terms(bool_should_list, "tags.market_tag.status", [tag])
-            if tag in ["主板上市", "创业板上市", "科创板上市", "新三板-基础层", "新三板-创新层", "新三板-精选层", "北交所"]:
+            if tag in ["主板上市", "创业板上市", "科创板上市", "新三板-基础层", "新三板-创新层", "新三板-精选层",
+                       "北交所"]:
                 es_condition_by_terms(bool_should_list, "tags.market_tag.block", [tag])
             # 其他  -此类不标准，尽量不要使用
             if tag in ["小巨人", "一条龙"]:
